@@ -1,5 +1,4 @@
 # Copyright Kevin Deldycke <kevin@deldycke.com> and contributors.
-# All Rights Reserved.
 #
 # This program is Free Software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -318,7 +317,7 @@ class DuplicateSet:
         # Duplicate sets matching none are skipped altogether.
         if candidate_count == 0:
             logger.warning(
-                f"Skip set: No mail within were selected. "
+                "Skip set: No mail within were selected. "
                 "The strategy criterion was not able to select some."
             )
             self.stats["mail_skipped"] += self.size
